==> setroubleshoot-plugins_2.0.18.orig.tar.gz: setroubleshoot-plugins-2.0.18/src/samba_enable_home_dirs.py <==
#
# Copyright (C) 2006,2008 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gettext
_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext

from setroubleshoot.util import *
from setroubleshoot.Plugin import Plugin

class plugin(Plugin):
    summary =_('''
    SELinux is preventing the samba daemon from reading users' home directories.
    ''')

    problem_description = _('''
    SELinux has denied the samba daemon access to users' home
    directories. Someone is attempting to access your home directories
    via your samba daemon. If you only setup samba to share non-home
    directories, this probably signals a intrusion attempt.
    For more information on SELinux integration with samba, look at the
    samba_selinux man page. (man samba_selinux)
    ''')

    fix_description = _('''
    If you want samba to share home directories you need to turn on
    the $BOOLEAN boolean: "setsebool -P $BOOLEAN=1"
    ''')

    fix_cmd = 'setsebool -P $BOOLEAN=1'
    
    def __init__(self):
        Plugin.__init__(self, __name__)

    def analyze(self, avc):
        if avc.matches_source_types(['smbd_t']) and \
           avc.matches_target_types(['home_root_t', '.*_home_dir_t', '.*_home_t']):
            # MATCH
            avc.set_template_substitutions(BOOLEAN="samba_enable_home_dirs")
            return self.report(avc, _("SAMBA"),
                               self.summary, self.problem_description,
                               self.fix_description, self.fix_cmd)
        else:
            return None

==> setroubleshoot-plugins_2.1.39.orig.tar.gz: setroubleshoot-plugins-2.1.39/src/samba_enable_home_dirs.py <==
#
# Copyright (C) 2006,2008 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gettext
translation=gettext.translation('setroubleshoot-plugins', fallback=True)
_=translation.ugettext

from setroubleshoot.util import *
from setroubleshoot.Plugin import Plugin

class plugin(Plugin):
    summary =_('''
    SELinux is preventing the samba daemon from reading users' home directories.
    ''')

    problem_description = _('''
    SELinux has denied the samba daemon access to users' home
    directories. Someone is attempting to access your home directories
    via your samba daemon. If you only setup samba to share non-home
    directories, this probably signals an intrusion attempt.
    For more information on SELinux integration with samba, look at the
    samba_selinux man page. (man samba_selinux)
    ''')

    fix_description = _('''
    If you want samba to share home directories you need to turn on
    the $BOOLEAN boolean: "setsebool -P $BOOLEAN=1"
    ''')

    fix_cmd = 'setsebool -P $BOOLEAN=1'
    
    def __init__(self):
        Plugin.__init__(self, __name__)

    def analyze(self, avc):
        if avc.matches_source_types(['smbd_t']) and \
           avc.matches_target_types(['home_root_t', '.*_home_dir_t', '.*_home_t']):
            # MATCH
            avc.set_template_substitutions(BOOLEAN="samba_enable_home_dirs")
            return self.report(avc, _("SAMBA"),
                               self.summary, self.problem_description,
                               self.fix_description, self.fix_cmd,
                               level="green")
        else:
            return None
